from .core import (
    print,
    patch_color,
    unpatch_color,
    patch_prefix,
    unpatch_prefix,
    info,
    warn,
    error,
    debug,
)

__all__ = [
    "print",
    "patch_color",
    "unpatch_color",
    "patch_prefix",
    "unpatch_prefix",
    "info",
    "warn",
    "error",
    "debug",
]

__version__ = "1.2.0"
